@@ -51,54 +51,58 @@
 /*
  * Global Variables
  */
-GtkWidget        *app;
-GtkWidget        *vbox;
-GtkWidget        *playing_area;
-GtkWidget        *statusbar;
-GtkWidget        *score_box;
-GdkGC            *draw_gc;
-GdkGC            *bg_gc;
-GdkGC            *slot_gc;
-GdkPixmap        *surface;
-GdkPixmap        *moving_card_pixmap;
-gchar            *card_style;
-gboolean         dont_save = FALSE; /* If the game is selected on the
-                                     * command line we assume that it is
-                                     * special and don't save the state.
-                                     * This is essential for Freecell
-                                     * emulation.*/
+GtkWidget *app;
+GtkWidget *vbox;
+GtkWidget *playing_area;
+GtkWidget *statusbar;
+GtkWidget *score_box;
+GdkGC *draw_gc;
+GdkGC *bg_gc;
+GdkGC *slot_gc;
+GdkPixmap *surface;
+GdkPixmap *moving_card_pixmap;
+gchar *card_style;
+gboolean dont_save = FALSE;	/* If the game is selected on the
+				 * command line we assume that it is
+				 * special and don't save the state.
+				 * This is essential for Freecell
+				 * emulation.*/
 
-gboolean	 droppable_is_featured;
-gboolean	 score_is_hidden; 
+gboolean droppable_is_featured;
+gboolean score_is_hidden;
 
-guint            score;
-guint            timeout;
-guint32          seed;
-gchar            *game_file = "";
-gchar            *game_name;
-gboolean         game_in_progress = FALSE;
-gboolean         game_over;
-gboolean         game_won;
-gboolean         click_to_move = FALSE;
-gchar            *variation = "";
-gchar            *gamesdir;
+guint score;
+guint timeout;
+guint32 seed;
+gchar *game_file = "";
+gchar *game_name;
+gboolean game_in_progress = FALSE;
+gboolean game_over;
+gboolean game_won;
+gboolean click_to_move = FALSE;
+gchar *variation = "";
+gchar *gamesdir;
 
-GConfClient      *gconf_client = NULL;
+GConfClient *gconf_client = NULL;
 
 #define DEFAULT_VARIATION "klondike.scm"
 #define GNOME_SESSION_BUG
 
-gchar* game_file_to_name (const gchar* file)
+gchar *
+game_file_to_name (const gchar * file)
 {
-  char* p, *buf = g_path_get_basename(file);
+  char *p, *buf = g_path_get_basename (file);
   gchar *ts;
 
-  if ((p = strrchr (buf, '.'))) *p = '\0';
-  for (p = buf; p = strchr(p, '_'), p && *p;) *p = ' ';
-  for (p = buf; p = strchr(p, '-'), p && *p;) *p = ' ';
-  for (p = buf; p = strchr(p, ' '), p && *p;) {
-    if (*(p+1)) {
-      *(p+1) = g_ascii_toupper (*(p+1));
+  if ((p = strrchr (buf, '.')))
+    *p = '\0';
+  for (p = buf; p = strchr (p, '_'), p && *p;)
+    *p = ' ';
+  for (p = buf; p = strchr (p, '-'), p && *p;)
+    *p = ' ';
+  for (p = buf; p = strchr (p, ' '), p && *p;) {
+    if (*(p + 1)) {
+      *(p + 1) = g_ascii_toupper (*(p + 1));
       p++;
     }
   }
@@ -130,11 +134,11 @@ game_file_to_help_section (const gchar * file)
   return buf;
 }
 
-
 /* Note that this is not the inverse of game_file_to_name. This
  * only works on untranslated names. game_file_to_name only produces
  * translated names. Be careful. */
-static gchar * game_name_to_file (const gchar *name)
+static gchar *
+game_name_to_file (const gchar * name)
 {
   char *p, *s;
 
@@ -147,7 +151,7 @@ static gchar * game_name_to_file (const gchar *name)
     p++;
   }
 
-  if (!g_str_has_suffix (s, ".scm")) { /* We may have been given a filename. */
+  if (!g_str_has_suffix (s, ".scm")) {	/* We may have been given a filename. */
     p = s;
     s = g_strconcat (s, ".scm", NULL);
     g_free (p);
@@ -159,35 +163,37 @@ static gchar * game_name_to_file (const gchar *name)
   return p;
 }
 
-void eval_installed_file (char *file)
+void
+eval_installed_file (char *file)
 {
   char *installed_filename;
   char *relative;
-  
-  if (g_file_test (file, G_FILE_TEST_EXISTS)){
+
+  if (g_file_test (file, G_FILE_TEST_EXISTS)) {
     scm_c_primitive_load (file);
     return;
   }
-  
-  relative = g_strconcat (GAMESDIR, file, NULL);
-  installed_filename = gnome_program_locate_file (NULL, 
-                                                  GNOME_FILE_DOMAIN_APP_DATADIR,
-                                                  relative,
-                                                  FALSE, NULL);
 
-  if (g_file_test (installed_filename, G_FILE_TEST_EXISTS)){
+  relative = g_strconcat (GAMESDIR, file, NULL);
+  installed_filename = gnome_program_locate_file (NULL,
+						  GNOME_FILE_DOMAIN_APP_DATADIR,
+						  relative, FALSE, NULL);
+
+  if (g_file_test (installed_filename, G_FILE_TEST_EXISTS)) {
     scm_c_primitive_load (installed_filename);
   } else {
-    char *message = g_strdup_printf (
-         _("Aisleriot can't load the file: \n%s\n\n"
-           "Please check your Aisleriot installation"), installed_filename);
+    char *message =
+      g_strdup_printf (_
+		       ("Aisleriot can't load the file: \n%s\n\n"
+			"Please check your Aisleriot installation"),
+		       installed_filename);
     GtkWidget *w = gtk_message_dialog_new (NULL, 0,
 					   GTK_MESSAGE_ERROR,
 					   GTK_BUTTONS_OK,
 					   message);
 
-    gtk_dialog_run (GTK_DIALOG(w));
-    gtk_widget_destroy(w);
+    gtk_dialog_run (GTK_DIALOG (w));
+    gtk_widget_destroy (w);
     g_free (message);
     exit (1);
   }
@@ -196,12 +202,12 @@ void eval_installed_file (char *file)
 }
 
 static int
-save_state (GnomeClient *client)
+save_state (GnomeClient * client)
 {
   gconf_client_set_string (gconf_client, "/apps/aisleriot/game_file",
-                           game_file, NULL);
+			   game_file, NULL);
   gconf_client_set_string (gconf_client, "/apps/aisleriot/card_style",
-                           card_style, NULL);
+			   card_style, NULL);
 
   return TRUE;
 }
@@ -210,7 +216,8 @@ save_state (GnomeClient *client)
    a default if it isn't found. */
 /* FIXME: There is a lot of duplication with the eval_installed_file
    function, but we need this called earlier. */
-static void check_game_file_name (void)
+static void
+check_game_file_name (void)
 {
   gchar *fullpath;
   gchar *partialpath;
@@ -219,14 +226,16 @@ static void check_game_file_name (void)
   partialpath = g_strconcat (GAMESDIR, game_file, NULL);
   fullpath = gnome_program_locate_file (NULL,
 					GNOME_FILE_DOMAIN_APP_DATADIR,
-					partialpath,
-					FALSE, NULL);
+					partialpath, FALSE, NULL);
   if (!g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
     dialog = gtk_message_dialog_new (NULL, 0,
 				     GTK_MESSAGE_INFO,
 				     GTK_BUTTONS_OK,
-				     _("Aisleriot cannot find the last game you played."));
- gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), _("This usually occurs when you run an older version of Aisleriot which does not have the game you last played. The default game, Klondike, is being started instead."));
+				     _
+				     ("Aisleriot cannot find the last game you played."));
+    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+					      _
+					      ("This usually occurs when you run an older version of Aisleriot which does not have the game you last played. The default game, Klondike, is being started instead."));
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     game_file = DEFAULT_VARIATION;
@@ -236,7 +245,8 @@ static void check_game_file_name (void)
   g_free (partialpath);
 }
 
-void new_game (gchar* file, guint *seedp)
+void
+new_game (gchar * file, guint * seedp)
 {
   double width, height;
 
@@ -251,13 +261,13 @@ void new_game (gchar* file, guint *seedp)
 
   if (file && strcmp (file, game_file)) {
     game_file = file;
-    
+
     /* Although this line slows down game switching by a noticeable amount, we
      * add it here in order to make sure all the original functions are
      * "clean". */
     eval_installed_file ("sol.scm");
     /* This is here so that the previous lines can catch bad installations 
-       and report it before reporting the fallback to defaults. */
+     * and report it before reporting the fallback to defaults. */
     check_game_file_name ();
     eval_installed_file (game_file);
 
@@ -278,84 +288,94 @@ void new_game (gchar* file, guint *seedp)
 
   if (seedp) {
     seed = *seedp;
-  }
-  else {
-    seed = g_random_int();
+  } else {
+    seed = g_random_int ();
   }
 
-  g_random_set_seed(seed);
-  set_score(0);
+  g_random_set_seed (seed);
+  set_score (0);
   timer_reset ();
 
-  cscmi_start_game_lambda(&width, &height);
+  cscmi_start_game_lambda (&width, &height);
   scm_c_eval_string ("(start-game)");
 
-  set_geometry(width, height);
+  set_geometry (width, height);
 
   /* It is possible for some games to not have any moves right from the
    * start. If this happens we redeal. */
-  if (!cscmi_game_over_lambda()) {
+  if (!cscmi_game_over_lambda ()) {
     new_game (file, NULL);
   } else {
     if (surface)
-      refresh_screen();
-    
+      refresh_screen ();
+
     undo_set_sensitive (FALSE);
     redo_set_sensitive (FALSE);
 
     game_over = FALSE;
-    gtk_window_set_title (GTK_WINDOW (app), _(game_name)); 
+    gtk_window_set_title (GTK_WINDOW (app), _(game_name));
   }
+  /* We've just started a new game. Add this to the list of games the user likes */
+  add_recently_played_game (file);
 }
 
 GtkWidget *score_value;
 
 guint score;
 
-void set_score(guint new_score) 
+void
+set_score (guint new_score)
 {
-  char b [10];
+  char b[10];
   score = new_score;
   g_snprintf (b, sizeof (b), "%6d  ", score);
-  gtk_label_set_text(GTK_LABEL(score_value), b);
+  gtk_label_set_text (GTK_LABEL (score_value), b);
 }
 
-guint get_score()
+guint
+get_score ()
 {
   return score;
 }
 
 GtkWidget *time_value;
 
-static gint timer_cb ()
+static gint
+timer_cb ()
 {
   timeout = 3600;
   /* All the games return #f and nothing else with this call, but just in
    * case someone changes their mind in the future. */
   if (cscmi_timeout_lambda ())
-    end_of_game_test();
-  return 0;	
+    end_of_game_test ();
+  return 0;
 }
 
 guint timer_timeout = 0;
 
-void timer_restart (void)
+void
+timer_restart (void)
 {
   games_clock_start (GAMES_CLOCK (time_value));
-  timer_timeout = g_timeout_add (timeout*1000 - timer_get (), (GSourceFunc) (timer_cb), NULL);
+  timer_timeout =
+    g_timeout_add (timeout * 1000 - timer_get (), (GSourceFunc) (timer_cb),
+		   NULL);
 }
 
-void timer_start (void)
+void
+timer_start (void)
 {
   if (timer_timeout)
     games_clock_stop (GAMES_CLOCK (time_value));
   timeout = 3600;
   games_clock_set_seconds (GAMES_CLOCK (time_value), 0);
   games_clock_start (GAMES_CLOCK (time_value));
-  timer_timeout = g_timeout_add (timeout * 1000, (GSourceFunc) (timer_cb), NULL);
+  timer_timeout =
+    g_timeout_add (timeout * 1000, (GSourceFunc) (timer_cb), NULL);
 }
 
-void timer_stop (void)
+void
+timer_stop (void)
 {
   games_clock_stop (GAMES_CLOCK (time_value));
   if (timer_timeout)
@@ -363,13 +383,15 @@ void timer_stop (void)
   timer_timeout = 0;
 }
 
-void timer_reset (void)
+void
+timer_reset (void)
 {
   timer_stop ();
   games_clock_set_seconds (GAMES_CLOCK (time_value), 0);
 }
 
-guint timer_get (void)
+guint
+timer_get (void)
 {
   return (guint) games_clock_get_seconds (GAMES_CLOCK (time_value));
 }
@@ -379,44 +401,46 @@ guint timer_get (void)
  */
 
 
-static void create_sol_board ()
+static void
+create_sol_board ()
 {
   playing_area = gtk_drawing_area_new ();
-  gtk_widget_set_events (playing_area, 
+  gtk_widget_set_events (playing_area,
 			 gtk_widget_get_events (playing_area) | GAME_EVENTS);
   /* This only enforces the minimum size. It is actually set using the
    * window size. */
-  gtk_widget_set_size_request (playing_area, BOARD_MIN_WIDTH, 
+  gtk_widget_set_size_request (playing_area, BOARD_MIN_WIDTH,
 			       BOARD_MIN_HEIGHT);
 
   gtk_box_pack_start (GTK_BOX (vbox), playing_area, TRUE, TRUE, 0);
-  
+
   gtk_widget_realize (playing_area);
 
   draw_gc = gdk_gc_new (playing_area->window);
-  
+
   bg_gc = gdk_gc_new (playing_area->window);
   if (get_background_pixmap ())
-    gdk_gc_set_tile (bg_gc, get_background_pixmap());
-  gdk_gc_set_fill (bg_gc, GDK_TILED);  
+    gdk_gc_set_tile (bg_gc, get_background_pixmap ());
+  gdk_gc_set_fill (bg_gc, GDK_TILED);
 
   slot_gc = gdk_gc_new (playing_area->window);
 
-  g_signal_connect (G_OBJECT(playing_area),"button_release_event",
-		      GTK_SIGNAL_FUNC (button_release_event), NULL);
+  g_signal_connect (G_OBJECT (playing_area), "button_release_event",
+		    GTK_SIGNAL_FUNC (button_release_event), NULL);
   g_signal_connect (G_OBJECT (playing_area), "motion_notify_event",
-		      GTK_SIGNAL_FUNC (motion_notify_event), NULL);
+		    GTK_SIGNAL_FUNC (motion_notify_event), NULL);
   g_signal_connect (G_OBJECT (playing_area), "button_press_event",
-		      GTK_SIGNAL_FUNC (button_press_event), NULL);
+		    GTK_SIGNAL_FUNC (button_press_event), NULL);
   g_signal_connect (G_OBJECT (playing_area), "configure_event",
-		      GTK_SIGNAL_FUNC (configure_event), NULL);
+		    GTK_SIGNAL_FUNC (configure_event), NULL);
   g_signal_connect (G_OBJECT (playing_area), "expose_event",
 		    GTK_SIGNAL_FUNC (expose_event), NULL);
   /* No need for gtk's double buffering, since we have our own. */
-  gtk_widget_set_double_buffered(playing_area, FALSE);
+  gtk_widget_set_double_buffered (playing_area, FALSE);
 }
 
-void quit_app (GtkMenuItem *menuitem)
+void
+quit_app (GtkMenuItem * menuitem)
 {
   /* If the game isn't over, then it counts as a failure. */
   if (game_in_progress) {
@@ -426,9 +450,64 @@ void quit_app (GtkMenuItem *menuitem)
   gtk_main_quit ();
 }
 
-static void create_main_window ()
+/*
+ * Takes the name of the file that drives the game and
+ * stores it as a recently played game
+ * Recent games are stored at the end of the list.
+ */
+void
+add_recently_played_game (gchar * game_file)
 {
-  GConfClient * gconf_client = gconf_client_get_default ();
+  if (game_file == NULL)
+    return;
+
+  GConfClient *gconf_client = gconf_client_get_default ();
+
+  gchar *recent_games =
+    gconf_client_get_string (gconf_client, RECENT_GAMES_GCONF_KEY, NULL);
+  gchar *new_games = NULL;
+
+  if (recent_games == NULL)
+    new_games = g_strdup (game_file);
+  else {
+    gchar **games_list = g_strsplit (recent_games, (gchar *) ",", 0);
+
+    /* Start off with our latest game at the front */
+    new_games = g_strdup (game_file);
+    int game_count = 1;
+    int index = 0;
+
+    while ((games_list[index] != NULL) && (game_count < 5)) {
+      /* If the game is already in the list, don't add it again */
+      if (g_ascii_strcasecmp (game_file, games_list[index]) == 0) {
+	++index;
+	continue;
+      }
+      new_games =
+	g_strconcat (new_games, (gchar *) ",", games_list[index], NULL);
+
+      ++game_count;
+      ++index;
+    }
+
+    new_games = g_strconcat (new_games, NULL);
+    g_strfreev (games_list);
+  }
+
+  /* Update the gconf key with the new list of games */
+  gconf_client_set_string (gconf_client, RECENT_GAMES_GCONF_KEY, new_games,
+			   NULL);
+
+  g_free (recent_games);
+  g_free (new_games);
+
+  install_recently_played_menu ();
+}
+
+static void
+create_main_window ()
+{
+  GConfClient *gconf_client = gconf_client_get_default ();
   gint width, height;
 
   width = gconf_client_get_int (gconf_client, WIDTH_GCONF_KEY, NULL);
@@ -439,19 +518,20 @@ static void create_main_window ()
 
   gtk_widget_realize (app);
 
-  g_signal_connect (GTK_OBJECT (app), "delete_event", 
-		      GTK_SIGNAL_FUNC (quit_app), NULL);
+  g_signal_connect (GTK_OBJECT (app), "delete_event",
+		    GTK_SIGNAL_FUNC (quit_app), NULL);
   g_signal_connect (GTK_OBJECT (app), "configure_event",
-		      GTK_SIGNAL_FUNC (app_configure_event), NULL);
+		    GTK_SIGNAL_FUNC (app_configure_event), NULL);
 }
 
-gchar* start_game;
+gchar *start_game;
 
-static void main_prog(void *closure, int argc, char *argv[])
+static void
+main_prog (void *closure, int argc, char *argv[])
 {
   GtkWidget *score_label, *time_label, *time_box;
 
-  cscm_init();
+  cscm_init ();
 
   create_main_window ();
   vbox = gtk_vbox_new (FALSE, 0);
@@ -465,23 +545,24 @@ static void main_prog(void *closure, int argc, char *argv[])
   create_menus ();
 
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);  
+  gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
   create_sol_board ();
   gtk_box_pack_end (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
   time_box = gtk_hbox_new (0, FALSE);
   score_box = gtk_hbox_new (0, FALSE);
   score_label = gtk_label_new (_("Score:"));
-  gtk_box_pack_start (GTK_BOX(score_box), score_label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (score_box), score_label, FALSE, FALSE, 0);
   score_value = gtk_label_new ("   0");
-  gtk_box_pack_start (GTK_BOX(score_box), score_value, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX(time_box), score_box, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (score_box), score_value, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (time_box), score_box, FALSE, FALSE, 0);
   time_label = gtk_label_new (_("Time:"));
-  gtk_box_pack_start (GTK_BOX(time_box), time_label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (time_box), time_label, FALSE, FALSE, 0);
   time_value = games_clock_new ();
-  gtk_box_pack_start (GTK_BOX(time_box), time_value, FALSE, FALSE, GNOME_PAD_SMALL);
+  gtk_box_pack_start (GTK_BOX (time_box), time_value, FALSE, FALSE,
+		      GNOME_PAD_SMALL);
 
-  gtk_box_pack_end (GTK_BOX(statusbar), time_box, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (statusbar), time_box, FALSE, FALSE, 0);
 
   new_game (start_game, NULL);
 
@@ -495,11 +576,11 @@ static void main_prog(void *closure, int argc, char *argv[])
   gtk_window_set_focus (GTK_WINDOW (app), NULL);
 
   if (!gconf_client_get_bool (gconf_client,
-                             "/apps/aisleriot/show_toolbar", NULL))
+			      "/apps/aisleriot/show_toolbar", NULL))
     gtk_widget_hide (toolbar);
 
-  click_to_move = gconf_client_get_bool (gconf_client, 
-					 "/apps/aisleriot/click_to_move", 
+  click_to_move = gconf_client_get_bool (gconf_client,
+					 "/apps/aisleriot/click_to_move",
 					 NULL);
 
   create_press_data (playing_area->window);
@@ -508,29 +589,29 @@ static void main_prog(void *closure, int argc, char *argv[])
 
   gnome_accelerators_sync ();
 
-  free_pixmaps();
+  free_pixmaps ();
   g_object_unref (surface);
 }
 
 static void
-retrieve_state (GnomeClient *client)
+retrieve_state (GnomeClient * client)
 {
   start_game = games_gconf_get_string (gconf_client,
-                                       "/apps/aisleriot/game_file",
-                                       "klondike.scm");
+				       "/apps/aisleriot/game_file",
+				       "klondike.scm");
   card_style = games_gconf_get_string (gconf_client,
-				       THEME_GCONF_KEY,
-				       "bonded.svg");
+				       THEME_GCONF_KEY, "bonded.svg");
 }
 
-int main (int argc, char *argv [])
+int
+main (int argc, char *argv[])
 {
   static const GOptionEntry aisleriot_opts[] = {
     {"variation", 'v', 0, G_OPTION_ARG_STRING, &variation,
      N_("Select the game to play"), N_("NAME")},
     {NULL}
   };
-  gchar * var_file;
+  gchar *var_file;
   GOptionContext *option_context;
   GnomeProgram *program;
 
@@ -540,11 +621,10 @@ int main (int argc, char *argv [])
 
   option_context = g_option_context_new ("");
   g_option_context_add_main_entries (option_context,
-                                     aisleriot_opts,
-                                     GETTEXT_PACKAGE);
-  
+				     aisleriot_opts, GETTEXT_PACKAGE);
+
   program = gnome_program_init ("aisleriot", VERSION,
-				LIBGNOMEUI_MODULE, 
+				LIBGNOMEUI_MODULE,
 				argc, argv,
 				GNOME_PARAM_GOPTION_CONTEXT, option_context,
 				GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
@@ -552,30 +632,29 @@ int main (int argc, char *argv [])
 
   gconf_client = gconf_client_get_default ();
   games_gconf_sanity_check_string (gconf_client, "/apps/aisleriot/game_file");
-  gconf_client_add_dir (gconf_client, "/apps/aisleriot", 
+  gconf_client_add_dir (gconf_client, "/apps/aisleriot",
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-  gconf_client_notify_add (gconf_client, STATISTICS_KEY, 
+  gconf_client_notify_add (gconf_client, STATISTICS_KEY,
 			   (GConfClientNotifyFunc) load_statistics,
 			   NULL, NULL, NULL);
   load_statistics ();
-  
+
   gtk_window_set_default_icon_name ("gnome-aisleriot");
   g_signal_connect (GTK_OBJECT (gnome_master_client ()), "save_yourself",
-		      GTK_SIGNAL_FUNC (save_state), 
-		      (gpointer) g_path_get_basename(argv[0]));
+		    GTK_SIGNAL_FUNC (save_state),
+		    (gpointer) g_path_get_basename (argv[0]));
   g_signal_connect (GTK_OBJECT (gnome_master_client ()), "die",
-		      GTK_SIGNAL_FUNC (quit_app), NULL);
+		    GTK_SIGNAL_FUNC (quit_app), NULL);
 
   retrieve_state (gnome_master_client ());
 
   gamesdir = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-	                                GAMESDIR, FALSE, NULL);
+					GAMESDIR, FALSE, NULL);
 
   /* If we are asked for a specific game, check that it is valid. */
   if (variation && *variation) {
     var_file = game_name_to_file (variation);
-    if (g_file_test (var_file, G_FILE_TEST_EXISTS 
-                              | G_FILE_TEST_IS_REGULAR)) {
+    if (g_file_test (var_file, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
       dont_save = TRUE;
       start_game = g_path_get_basename (var_file);
     }
