@@ -27,10 +27,12 @@ else:
 from glchess.defaults import *
 
 # Optionally use OpenGL support
+# gtk.gtkgl throws RuntimeError when there is no OpenGL support
+# It should really just throw ImportError
 try:
     import gtk.gtkgl
     import OpenGL
-except ImportError:
+except (ImportError, RuntimeError):
     haveGLSupport = False
 else:
     haveGLSupport = True
@@ -89,8 +91,10 @@ class GtkViewArea(gtk.DrawingArea):
         
     def redraw(self):
         """Request this widget is redrawn"""
-        #FIXME: Check this is valid
-        self.window.invalidate_rect(self.allocation, False)
+        # If the window is visible prepare it for redrawing
+        area = gtk.gdk.Rectangle(0, 0, self.allocation.width, self.allocation.height)
+        if self.window is not None:
+            self.window.invalidate_rect(area, False)
 
     def setRenderGL(self, renderGL):
         """Enable OpenGL rendering"""
