@@ -30,18 +30,18 @@
 #define WARPLETTER 'W'
 
 typedef struct {
-	GnibblesWarp *warps[MAXWARPS];
-	gint numwarps;
+  GnibblesWarp *warps[MAXWARPS];
+  gint numwarps;
 } GnibblesWarpManager;
 
 GnibblesWarpManager *gnibbles_warpmanager_new (void);
 
-void gnibbles_warpmanager_destroy (GnibblesWarpManager *warpmanager);
+void gnibbles_warpmanager_destroy (GnibblesWarpManager * warpmanager);
 
-void gnibbles_warpmanager_add_warp (GnibblesWarpManager *warpmanager, gint t_x,
-		gint t_y, gint t_wx, gint t_wy);
+void gnibbles_warpmanager_add_warp (GnibblesWarpManager * warpmanager,
+				    gint t_x, gint t_y, gint t_wx, gint t_wy);
 
-void gnibbles_warpmanager_worm_change_pos (GnibblesWarpManager *warpmanager,
-		GnibblesWorm *worm);
+void gnibbles_warpmanager_worm_change_pos (GnibblesWarpManager * warpmanager,
+					   GnibblesWorm * worm);
 
 #endif
